***************************************************************************
 RESEARCHER: Ron Collins                     PROGRAM FILE: rc1390MsTable1.sas
      STUDY: Ecuador Spray Treatments           DATA FILE: rc1390.csv

  INSTITUTE: PSI                              BIOMETRICIAN: Mary J. Camp
        LAB: SPC
 PROJECT ID: 12025

 DATE STARTED: July 24, 2017 (modified for distribution 4/6/18)
****************************************************************************;
title 'Collins -- Ecuador Spray Treatments (12025)';
options nodate ls=95 ps=66 pageno=1;

*----------------------*
| Trt Codes:           |
|  1=OIC  2=WC  3=Oil  |
*----------------------*;

** Define drive and where data set is **;

%let drive=c;

data a; infile "&drive:/rc1390.csv" delimiter="," firstobs=2;
input Exp Trt Tree Card DV5 Coverage Deposits Deposition Mean Std Q2 Q3 Q1 IQR RS;
  if trt=3 then delete;
  drop Mean -- IQR;
run;

proc print data=a uniform;
  title 'Data';
quit;

** Average the card subsamples by tree for per tree values **;
proc sort data=a; by exp trt tree;
quit;

proc means data=a noprint mean; by exp trt tree;
  var DV5 coverage deposits deposition rs;
  output out=ma mean=DV5 Coverage Deposits Deposition RS;
quit;

data ma; set ma;
  drop _TYPE_;
run;

proc print data=ma uniform;
  title 'Data for Analysis';
quit;

** Analysis for Ms Table 1 **;
%macro amix(var);
  proc mixed data=ma noinfo ratio;
    class exp trt;
    model &var= trt/ ddfm=kr outpred=res;
    random exp;
    lsmeans trt/pdiff;
    title "Var: &var";
  run;

  proc means data=res maxdec=2 n Q1 Median Q3 QRange;
   class Trt;
   var &var Pred;
  quit;
%mend amix;


%amix(DV5);

%amix(Coverage);

%amix(Deposits);

%amix(Deposition);

%amix(RS);
