***************************************************************************
 RESEARCHER: Ron Collins                  PROGRAM FILE: rc139Data926 MsTables2and3.sas
      STUDY: Ecuador Spray Treatments        DATA FILE: rc139data926C.csv

  INSTITUTE: PSI                          BIOMETRICIAN: Mary J. Camp
        LAB: SPC
 PROJECT ID: 12025

 DATE STARTED: September 26, 2017 (modified for distribution 4/6/18)
****************************************************************************;
title 'Collins -- Ecuador Spray Treatments (12025)';
options nodate ls=95 ps=66 pageno=1;

*----------------------*
| Trt Codes:           |
|  1=OIC  2=WC  3=Oil  |
*----------------------*;

** Define drive and where data set is **;

%let drive=c;

data a; infile "&drive:/rc139data926C.csv" delimiter="," firstobs=2;
input Exp Treat$ Trt Tree Card DV5 Coverage Deposits Deposition RSF;
  if trt=3 then delete;
run;

proc print data=a uniform;
  title 'Raw Data';
quit;

** Average the card subsamples by tree for per tree values **;
proc sort data=a; by exp trt tree;
quit;

proc means data=a noprint mean; by exp trt tree;
  var DV5 coverage deposits deposition rsf;
  output out=ma mean=DV5 Coverage Deposits Deposition RSF;
quit;

proc print data=ma uniform;
  title 'Data for Analysis';
quit;

** Analysis for Ms Tables 2 and 3 **;
%macro amix(var);
  proc mixed data=ma noinfo ratio;
    class exp trt;
    model &var= exp trt/ ddfm=kr;
    lsmeans trt;
    title "Var: &var (Fixed Exp)";
  run;
%mend amix;

%amix(DV5);

%amix(Coverage);

%amix(Deposits);

%amix(Deposition);

%amix(RSF);

